@@ -21,7 +21,8 @@ from collections import deque
 
 
 class Config:
-  """Captures framework-level configurations.
+  """
+  Captures framework-level configurations.
   
   The Config object is a data structure built for the purpose of
   receiving and prioritizing configurations from multiple sources.
@@ -147,8 +148,8 @@ class Config:
   def __contains__(self, key):
     return key in self._attr
   
-  def items(self):
-    return { k:v['value'] for k,v in self._attr.items() }
+  def items(self, only_preserve=True):
+    return { k:v['value'] for k,v in self._attr.items() if v['preserve'] }
   
   @property
   def ctllog_file(self):
@@ -165,14 +166,15 @@ class Config:
       return '{}/{}.ctx'.format(self['temp_dir'], self['app_name'])
   
   def source_config_file(self, config_file):
-    """Sources config file to export environment variables.
+    """
+    Sources config file to export environment variables.
     
     Sources the given file in order to export environment variables
     prior to executing app/job instance. Only variables beginning with
     'APP_' will be preserved/exported, while other vars will be lost.
     
     Raises:
-        FileNotFoundError: Could not find specified file or is not a file.
+      FileNotFoundError: Could not find specified file or is not a file.
     """
     print('Sourcing File: {}'.format(config_file))
     if not config_file or not os.path.isfile(config_file):
