@@ -26,12 +26,10 @@ import pyrunner.core.constants as constants
 
 from pyrunner.core.engine import ExecutionEngine
 from pyrunner.core.config import Config
-from pyrunner.core.context import Context
 from pyrunner.core.register import NodeRegister
 from pyrunner.version import __version__
 
 from datetime import datetime as datetime
-from multiprocessing import Manager
 import pickle
 import time
 
@@ -41,29 +39,28 @@ class PyRunner:
     self.config = Config()
     self.notification = notification.EmailNotification()
     
-    # Initialization of Manager proxy objects and Context
-    self._manager = Manager()
-    self._shared_dict = self._manager.dict()
-    self._shared_queue = self._manager.Queue()
-    self.context = Context(self._shared_dict, self._shared_queue)
-    
-    self.register = NodeRegister(serde.ListSerDe(), self.context)
-    
-    # NodeRegister wiring
-    self.add_node      = self.register.add_node
-    self.exec_only     = self.register.exec_only
-    self.exec_to       = self.register.exec_to
-    self.exec_from     = self.register.exec_from
-    self.exec_disable  = self.register.exec_disable
-    self.load_workflow = self.register.load_from_file
+    self.serde_obj = serde.ListSerDe()
+    self.register = NodeRegister()
+    self.engine = None
     
     # Config wiring
     self.source_config_file = self.config.source_config_file
     
     # Backwards compatability
-    self.load_proc_list_file = self.register.load_from_file
+    self.load_proc_list_file = self.load_from_file
     self.load_last_failed = self.load_state
   
+  def load_from_file(self, proc_file, restart=False):
+    if not os.path.isfile(proc_file):
+      return False
+    
+    self.register = self.serde_obj.deserialize(proc_file, restart)
+    
+    if not self.register or not isinstance(self.register, NodeRegister):
+      return False
+    
+    return True
+  
   @property
   def version(self):
     return __version__
@@ -73,7 +70,7 @@ class PyRunner:
   
   def plugin_serde(self, obj):
     if not isinstance(obj, serde.SerDe): raise Exception('SerDe plugin must implement the SerDe interface')
-    self.register = NodeRegister(obj)
+    self.serde_obj = obj
   
   def plugin_notification(self, obj):
     if not isinstance(obj, notification.Notification): raise Exception('Notification plugin must implement the Notification interface')
@@ -83,18 +80,18 @@ class PyRunner:
     return self.run()
   def run(self):
     self.config['app_start_time'] = datetime.now().strftime('%Y-%m-%d %H:%M:%S')
-    engine = ExecutionEngine()
-    engine.config = self.config
-    engine.context = self.context
-    engine.register = self.register
-    engine.save_state_func = self.save_state
+    
+    self.engine = ExecutionEngine()
+    self.engine.config = self.config
+    self.engine.register = self.register
+    self.engine.save_state_func = self.save_state
     
     if self.config['dryrun']:
       self.print_documentation()
       return 0
     
     print('Executing PyRunner App: {}'.format(self.config['app_name']))
-    retcode = engine.initiate()
+    retcode = self.engine.initiate()
     
     if retcode == 0 and not self.config['email_on_success']:
       print('Skipping Email Notification: Property "email_on_success" is set to FALSE.')
@@ -179,13 +176,16 @@ class PyRunner:
     return zip_file
   
   def save_state(self, suppress_output=False):
-    self.register.save_to_file(self.config.ctllog_file, suppress_output)
+    if not suppress_output:
+      print('Saving Execution Graph File to: {}'.format(self.config.ctllog_file))
+
+    self.serde_obj.save_to_file(self.config.ctllog_file, self.register)
     
     try:
       
       state_obj = {
         'config'       : self.config.items(),
-        'shared_dict'  : self._shared_dict.copy()
+        'shared_dict'  : self.engine._shared_dict.copy()
       }
       
       if not suppress_output:
@@ -199,7 +199,7 @@ class PyRunner:
     return
   
   def load_state(self):
-    if not self.register.load_from_file(self.config.ctllog_file, True):
+    if not self.load_from_file(self.config.ctllog_file, True):
       return False
     
     if not os.path.isfile(self.config.ctx_file):
@@ -212,7 +212,7 @@ class PyRunner:
       self.config[k] = v
     
     for k,v in state_obj['shared_dict'].items():
-      self._shared_dict[k] = v
+      self.engine._shared_dict[k] = v
     
     return True
   
@@ -220,4 +220,12 @@ class PyRunner:
     if os.path.isfile(self.config.ctllog_file):
       os.remove(self.config.ctllog_file)
     if os.path.isfile(self.config.ctx_file):
-      os.remove(self.config.ctx_file)
\ No newline at end of file
+      os.remove(self.config.ctx_file)
+  
+  # NodeRegister wiring
+  def add_node(self, *args)       : self.register.add_node(*args)
+  def exec_only(self, *args)      : self.register.exec_only(*args)
+  def exec_to(self, *args)        : self.register.exec_to(*args)
+  def exec_from(self, *args)      : self.register.exec_from(*args)
+  def exec_disable(self, *args)   : self.register.exec_disable(*args)
+  def load_workflow (self, *args) : self.register.load_from_file(*args)
\ No newline at end of file
